@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright © 2006 - 2017 Michal Čihař <michal@cihar.com>
 #
@@ -17,25 +16,23 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-"""Main stardicter module"""
+"""Main stardicter module."""
 
 import codecs
 
 from stardicter.czech import CzechWriter
-from stardicter.czechgerman import CzechGermanWriter
 from stardicter.czechenglish import CzechEnglishWriter
-from stardicter.dictsinfo import DictsInfoWriter
+from stardicter.czechgerman import CzechGermanWriter
 from stardicter.deaccent import deaccent
+from stardicter.dictsinfo import DictsInfoWriter
 
 # List of known dictionaries writers
 DICTIONARIES = {
-    'czech': CzechWriter,
-    'czechgerman': CzechGermanWriter,
-    'czechenglish': CzechEnglishWriter,
-    'dictsinfo': DictsInfoWriter,
+    "czech": CzechWriter,
+    "czechgerman": CzechGermanWriter,
+    "czechenglish": CzechEnglishWriter,
+    "dictsinfo": DictsInfoWriter,
 }
 
 # Register deaccenting codec
-codecs.register_error('deaccent', deaccent)
-
-__version__ = '1.2'
+codecs.register_error("deaccent", deaccent)
